==> ejc-tax-impl-3.0.0-20230607.022329-330-sources.jar: com/ejianc/business/taxnew/bean/InvoiceOpenPoolEntity.java <==
package com.ejianc.business.taxnew.bean;

import java.math.BigDecimal;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 销项发票池
 * 
 * @author generator
 * 
 */
 @TableName("ejc_tax_invoice_open_pool")
public class InvoiceOpenPoolEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="bill_code")
    private String billCode; // 开票单号
    @TableField(value="contract_id")
    private Long contractId; // 合同id
    @TableField(value="contract_code")
    private String contractCode; // 合同编码
    @TableField(value="contract_name")
    private String contractName; // 合同名称
    @TableField(value="contract_type")
    private String contractType; // 合同类别
    @TableField(value="project_name")
    private String projectName; // 项目名称
    @TableField(value="project_id")
    private Long projectId; // 项目id
    @TableField(value="org_name")
    private String orgName; // 组织名称
    @TableField(value="org_id")
    private Long orgId; // 组织id
    @TableField(value="customer_id")
    private Long customerId; // 购方id
    @TableField(value="customer_credit_code")
    private String customerCreditCode; // 纳税人识别号
    @TableField(value="supplier_name")
    private String supplierName; // 销方名称
    @TableField(value="supplier_id")
    private Long supplierId; // 销方id
    @TableField(value="supplier_credit_code")
    private String supplierCreditCode; // 销方纳税人识别号
    @TableField(value="memo")
    private String memo; // 备注
    @TableField(value="type")
    private Integer type; // 开票类型:1,有合同,2,无合同
    @TableField(value="invoice_type")
    private Long invoiceType; // 发票类型:1、增值税专用发票，2、增值税普通发票，3、其他；
    @TableField(value="invoice_type_name")
    private String invoiceTypeName; // 发票类型名称:1、增值税专用发票，2、增值税普通发票，3、其他；
    @TableField(value="invoice_number")
    private String invoiceNumber; // 发票号码
    @TableField(value="invoice_code")
    private String invoiceCode; // 发票代码
    @TableField(value="invoice_date")
    private java.util.Date invoiceDate; // 开票日期
    @TableField(value="invoice_mny")
    private java.math.BigDecimal invoiceMny; // 发票金额（不含税）
    @TableField(value="tax_mny")
    private java.math.BigDecimal taxMny; // 税金
    @TableField(value="invoice_tax_mny")
    private java.math.BigDecimal invoiceTaxMny; // 价税合计

    /**
     * 使用的发票的金额
     */
    @TableField("use_invoice_tax_mny")
    private BigDecimal useInvoiceTaxMny;

    @TableField(value="bill_state")
    private Integer billState; // 单据状态（审批必须字段）
    @TableField(value="customer_name")
    private String customerName; // 购方名称
    @TableField(value="employee_name")
    private String employeeName; // 经办人名称
    @TableField(value="employee_id")
    private Long employeeId; // 经办人
    @TableField(value="apply_id")
    private Long applyId; // 申请单id
    @TableField(value="apply_code")
    private String applyCode; // 申请单编码
    @TableField(value="regist_id")
    private Long registId; // 开票登记单id
    @TableField(value="regist_code")
    private String registCode; // 开票登记单code

    @TableField(value="invoice_tax_mny_chn")
    private String invoiceTaxMnyChn; //价税合计大写

    @TableField(value="invoice_content")
    private String invoiceContent;

    @TableField(value="open_apply_type")
    private Integer openApplyType; //是否有申请 默认 0 无申请 1-有申请

    @TableField(value="apply_mny_tax")
    private java.math.BigDecimal applyMnyTax; // 申请金额 含税

    @TableField(value="money_type_id")
    private Long moneyTypeId; // 款项类别id

    @TableField(value="buyer_bank_account")
    private String buyerBankAccount; // 购方开户行账号
    @TableField(value="buyer_addr_phone")
    private String buyerAddrPhone; // 购方地址电话
    @TableField(value="seller_bank_account")
    private String sellerBankAccount; // 销售方开户行账号
    @TableField(value="seller_addr_phone")
    private String sellerAddrPhone; // 销售方地址电话
    @TableField(value="origin_type")
    private Integer originType; // 来源方式 0、默认生成，1、手动录入，2、扫码录入，3OCR扫描，4系统下载
    @TableField(value="regist")
    private Integer regist; // 是否登记 0---登记未生效 1---登记已生效

    public BigDecimal getUseInvoiceTaxMny() {
        return useInvoiceTaxMny;
    }

    public void setUseInvoiceTaxMny(BigDecimal useInvoiceTaxMny) {
        this.useInvoiceTaxMny = useInvoiceTaxMny;
    }

    /**
     * 开票单号
     */
    public String getBillCode() {
        return billCode;
    }

    /**
     * 开票单号
     */
    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    /**
     * 合同id
     */
    public Long getContractId() {
        return contractId;
    }

    /**
     * 合同id
     */
    public void setContractId(Long contractId) {
        this.contractId = contractId;
    }
    /**
     * 合同编码
     */
    public String getContractCode() {
        return contractCode;
    }

    /**
     * 合同编码
     */
    public void setContractCode(String contractCode) {
        this.contractCode = contractCode;
    }
    /**
     * 合同名称
     */
    public String getContractName() {
        return contractName;
    }

    /**
     * 合同名称
     */
    public void setContractName(String contractName) {
        this.contractName = contractName;
    }
    /**
     * 合同类别
     */
    public String getContractType() {
        return contractType;
    }

    /**
     * 合同类别
     */
    public void setContractType(String contractType) {
        this.contractType = contractType;
    }
    /**
     * 项目名称
     */
    public String getProjectName() {
        return projectName;
    }

    /**
     * 项目名称
     */
    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    /**
     * 项目id
     */
    public Long getProjectId() {
        return projectId;
    }

    /**
     * 项目id
     */
    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    /**
     * 组织名称
     */
    public String getOrgName() {
        return orgName;
    }

    /**
     * 组织名称
     */
    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    /**
     * 组织id
     */
    public Long getOrgId() {
        return orgId;
    }

    /**
     * 组织id
     */
    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    /**
     * 购方id
     */
    public Long getCustomerId() {
        return customerId;
    }

    /**
     * 购方id
     */
    public void setCustomerId(Long customerId) {
        this.customerId = customerId;
    }
    /**
     * 纳税人识别号
     */
    public String getCustomerCreditCode() {
        return customerCreditCode;
    }

    /**
     * 纳税人识别号
     */
    public void setCustomerCreditCode(String customerCreditCode) {
        this.customerCreditCode = customerCreditCode;
    }
    /**
     * 销方名称
     */
    public String getSupplierName() {
        return supplierName;
    }

    /**
     * 销方名称
     */
    public void setSupplierName(String supplierName) {
        this.supplierName = supplierName;
    }
    /**
     * 销方id
     */
    public Long getSupplierId() {
        return supplierId;
    }

    /**
     * 销方id
     */
    public void setSupplierId(Long supplierId) {
        this.supplierId = supplierId;
    }
    /**
     * 销方纳税人识别号
     */
    public String getSupplierCreditCode() {
        return supplierCreditCode;
    }

    /**
     * 销方纳税人识别号
     */
    public void setSupplierCreditCode(String supplierCreditCode) {
        this.supplierCreditCode = supplierCreditCode;
    }
    /**
     * 备注
     */
    public String getMemo() {
        return memo;
    }

    /**
     * 备注
     */
    public void setMemo(String memo) {
        this.memo = memo;
    }
    /**
     * 开票类型:1,有合同,2,无合同
     */
    public Integer getType() {
        return type;
    }

    /**
     * 开票类型:1,有合同,2,无合同
     */
    public void setType(Integer type) {
        this.type = type;
    }
    /**
     * 发票类型:1、增值税专用发票，2、增值税普通发票，3、其他；
     */
    public Long getInvoiceType() {
        return invoiceType;
    }

    public void setInvoiceType(Long invoiceType) {
        this.invoiceType = invoiceType;
    }

    /**
     * 发票类型名称:1、增值税专用发票，2、增值税普通发票，3、其他；
     */
    public String getInvoiceTypeName() {
        return invoiceTypeName;
    }

    /**
     * 发票类型名称:1、增值税专用发票，2、增值税普通发票，3、其他；
     */
    public void setInvoiceTypeName(String invoiceTypeName) {
        this.invoiceTypeName = invoiceTypeName;
    }
    /**
     * 发票号码
     */
    public String getInvoiceNumber() {
        return invoiceNumber;
    }

    /**
     * 发票号码
     */
    public void setInvoiceNumber(String invoiceNumber) {
        this.invoiceNumber = invoiceNumber;
    }
    /**
     * 发票代码
     */
    public String getInvoiceCode() {
        return invoiceCode;
    }

    /**
     * 发票代码
     */
    public void setInvoiceCode(String invoiceCode) {
        this.invoiceCode = invoiceCode;
    }
    /**
     * 开票日期
     */
    public java.util.Date getInvoiceDate() {
        return invoiceDate;
    }

    /**
     * 开票日期
     */
    public void setInvoiceDate(java.util.Date invoiceDate) {
        this.invoiceDate = invoiceDate;
    }
    /**
     * 发票金额（不含税）
     */
    public java.math.BigDecimal getInvoiceMny() {
        return invoiceMny;
    }

    /**
     * 发票金额（不含税）
     */
    public void setInvoiceMny(java.math.BigDecimal invoiceMny) {
        this.invoiceMny = invoiceMny;
    }
    /**
     * 税金
     */
    public java.math.BigDecimal getTaxMny() {
        return taxMny;
    }

    /**
     * 税金
     */
    public void setTaxMny(java.math.BigDecimal taxMny) {
        this.taxMny = taxMny;
    }
    /**
     * 价税合计
     */
    public java.math.BigDecimal getInvoiceTaxMny() {
        return invoiceTaxMny;
    }

    /**
     * 价税合计
     */
    public void setInvoiceTaxMny(java.math.BigDecimal invoiceTaxMny) {
        this.invoiceTaxMny = invoiceTaxMny;
    }
    /**
     * 单据状态（审批必须字段）
     */
    public Integer getBillState() {
        return billState;
    }

    /**
     * 单据状态（审批必须字段）
     */
    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    /**
     * 购方名称
     */
    public String getCustomerName() {
        return customerName;
    }

    /**
     * 购方名称
     */
    public void setCustomerName(String customerName) {
        this.customerName = customerName;
    }
    /**
     * 经办人名称
     */
    public String getEmployeeName() {
        return employeeName;
    }

    /**
     * 经办人名称
     */
    public void setEmployeeName(String employeeName) {
        this.employeeName = employeeName;
    }
    /**
     * 经办人
     */
    public Long getEmployeeId() {
        return employeeId;
    }

    /**
     * 经办人
     */
    public void setEmployeeId(Long employeeId) {
        this.employeeId = employeeId;
    }
    /**
     * 申请单id
     */
    public Long getApplyId() {
        return applyId;
    }

    /**
     * 申请单id
     */
    public void setApplyId(Long applyId) {
        this.applyId = applyId;
    }
    /**
     * 申请单编码
     */
    public String getApplyCode() {
        return applyCode;
    }

    /**
     * 申请单编码
     */
    public void setApplyCode(String applyCode) {
        this.applyCode = applyCode;
    }
    /**
     * 开票登记单id
     */
    public Long getRegistId() {
        return registId;
    }

    /**
     * 开票登记单id
     */
    public void setRegistId(Long registId) {
        this.registId = registId;
    }
    /**
     * 开票登记单code
     */
    public String getRegistCode() {
        return registCode;
    }

    /**
     * 开票登记单code
     */
    public void setRegistCode(String registCode) {
        this.registCode = registCode;
    }

    public String getInvoiceTaxMnyChn() {
        return invoiceTaxMnyChn;
    }

    public void setInvoiceTaxMnyChn(String invoiceTaxMnyChn) {
        this.invoiceTaxMnyChn = invoiceTaxMnyChn;
    }

    public String getInvoiceContent() {
        return invoiceContent;
    }

    public void setInvoiceContent(String invoiceContent) {
        this.invoiceContent = invoiceContent;
    }

    public Integer getOpenApplyType() {
        return openApplyType;
    }

    public void setOpenApplyType(Integer openApplyType) {
        this.openApplyType = openApplyType;
    }

    public BigDecimal getApplyMnyTax() {
        return applyMnyTax;
    }

    public void setApplyMnyTax(BigDecimal applyMnyTax) {
        this.applyMnyTax = applyMnyTax;
    }

    public Long getMoneyTypeId() {
        return moneyTypeId;
    }

    public void setMoneyTypeId(Long moneyTypeId) {
        this.moneyTypeId = moneyTypeId;
    }

    public String getBuyerBankAccount() {
        return buyerBankAccount;
    }

    public void setBuyerBankAccount(String buyerBankAccount) {
        this.buyerBankAccount = buyerBankAccount;
    }

    public String getBuyerAddrPhone() {
        return buyerAddrPhone;
    }

    public void setBuyerAddrPhone(String buyerAddrPhone) {
        this.buyerAddrPhone = buyerAddrPhone;
    }

    public String getSellerBankAccount() {
        return sellerBankAccount;
    }

    public void setSellerBankAccount(String sellerBankAccount) {
        this.sellerBankAccount = sellerBankAccount;
    }

    public String getSellerAddrPhone() {
        return sellerAddrPhone;
    }

    public void setSellerAddrPhone(String sellerAddrPhone) {
        this.sellerAddrPhone = sellerAddrPhone;
    }

    public Integer getOriginType() {
        return originType;
    }

    public void setOriginType(Integer originType) {
        this.originType = originType;
    }

    public Integer getRegist() {
        return regist;
    }

    public void setRegist(Integer regist) {
        this.regist = regist;
    }
}

==> ejc-tax-impl-3.0.0-20250427.022219-437-sources.jar: com/ejianc/business/taxnew/bean/InvoiceOpenPoolEntity.java <==
package com.ejianc.business.taxnew.bean;

import java.math.BigDecimal;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 销项发票池
 * 
 * @author generator
 * 
 */
 @TableName("ejc_tax_invoice_open_pool")
public class InvoiceOpenPoolEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="bill_code")
    private String billCode; // 开票单号
    @TableField(value="contract_id")
    private Long contractId; // 合同id
    @TableField(value="contract_code")
    private String contractCode; // 合同编码
    @TableField(value="contract_name")
    private String contractName; // 合同名称
    @TableField(value="contract_type")
    private String contractType; // 合同类别
    @TableField(value="project_name")
    private String projectName; // 项目名称
    @TableField(value="project_id")
    private Long projectId; // 项目id
    @TableField(value="org_name")
    private String orgName; // 组织名称
    @TableField(value="org_id")
    private Long orgId; // 组织id
    @TableField(value="customer_id")
    private Long customerId; // 购方id
    @TableField(value="customer_credit_code")
    private String customerCreditCode; // 纳税人识别号
    @TableField(value="supplier_name")
    private String supplierName; // 销方名称
    @TableField(value="supplier_id")
    private Long supplierId; // 销方id
    @TableField(value="supplier_credit_code")
    private String supplierCreditCode; // 销方纳税人识别号
    @TableField(value="memo")
    private String memo; // 备注
    @TableField(value="type")
    private Integer type; // 开票类型:1,有合同,2,无合同
    @TableField(value="invoice_type")
    private Long invoiceType; // 发票类型:1、增值税专用发票，2、增值税普通发票，3、其他；
    @TableField(value="invoice_type_name")
    private String invoiceTypeName; // 发票类型名称:1、增值税专用发票，2、增值税普通发票，3、其他；
    @TableField(value="invoice_number")
    private String invoiceNumber; // 发票号码
    @TableField(value="invoice_code")
    private String invoiceCode; // 发票代码
    @TableField(value="invoice_date")
    private java.util.Date invoiceDate; // 开票日期
    @TableField(value="invoice_mny")
    private java.math.BigDecimal invoiceMny; // 发票金额（不含税）
    @TableField(value="tax_mny")
    private java.math.BigDecimal taxMny; // 税金
    @TableField(value="invoice_tax_mny")
    private java.math.BigDecimal invoiceTaxMny; // 价税合计
    /**
     * 税率
     */
    @TableField(value = "tax_rate")
    private Double taxRate;
    /**
     * 使用的发票的金额
     */
    @TableField("use_invoice_tax_mny")
    private BigDecimal useInvoiceTaxMny;

    @TableField(value="bill_state")
    private Integer billState; // 单据状态（审批必须字段）
    @TableField(value="customer_name")
    private String customerName; // 购方名称
    @TableField(value="employee_name")
    private String employeeName; // 经办人名称
    @TableField(value="employee_id")
    private Long employeeId; // 经办人
    @TableField(value="apply_id")
    private Long applyId; // 申请单id
    @TableField(value="apply_code")
    private String applyCode; // 申请单编码
    @TableField(value="regist_id")
    private Long registId; // 开票登记单id
    @TableField(value="regist_code")
    private String registCode; // 开票登记单code

    @TableField(value="invoice_tax_mny_chn")
    private String invoiceTaxMnyChn; //价税合计大写

    @TableField(value="invoice_content")
    private String invoiceContent;

    @TableField(value="open_apply_type")
    private Integer openApplyType; //是否有申请 默认 0 无申请 1-有申请

    @TableField(value="apply_mny_tax")
    private java.math.BigDecimal applyMnyTax; // 申请金额 含税

    @TableField(value="money_type_id")
    private Long moneyTypeId; // 款项属性id

    @TableField(value="buyer_bank_account")
    private String buyerBankAccount; // 购方开户行账号
    @TableField(value="buyer_addr_phone")
    private String buyerAddrPhone; // 购方地址电话
    @TableField(value="seller_bank_account")
    private String sellerBankAccount; // 销售方开户行账号
    @TableField(value="seller_addr_phone")
    private String sellerAddrPhone; // 销售方地址电话
    @TableField(value="origin_type")
    private Integer originType; // 来源方式 0、默认生成，1、手动录入，2、扫码录入，3OCR扫描，4系统下载
    @TableField(value="regist")
    private Integer regist; // 是否登记 0---登记未生效 1---登记已生效


    @TableField(value="money_kind_id")
    private Long moneyKindId; // 款项类别id
    @TableField(value="money_kind")
    private String moneyKind; // 款项类别名称

    public Long getMoneyKindId() {
        return moneyKindId;
    }

    public void setMoneyKindId(Long moneyKindId) {
        this.moneyKindId = moneyKindId;
    }

    public String getMoneyKind() {
        return moneyKind;
    }

    public void setMoneyKind(String moneyKind) {
        this.moneyKind = moneyKind;
    }

    public BigDecimal getUseInvoiceTaxMny() {
        return useInvoiceTaxMny;
    }

    public void setUseInvoiceTaxMny(BigDecimal useInvoiceTaxMny) {
        this.useInvoiceTaxMny = useInvoiceTaxMny;
    }

    /**
     * 开票单号
     */
    public String getBillCode() {
        return billCode;
    }

    public Double getTaxRate() {
        return taxRate;
    }

    public void setTaxRate(Double taxRate) {
        this.taxRate = taxRate;
    }

    /**
     * 开票单号
     */
    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    /**
     * 合同id
     */
    public Long getContractId() {
        return contractId;
    }

    /**
     * 合同id
     */
    public void setContractId(Long contractId) {
        this.contractId = contractId;
    }
    /**
     * 合同编码
     */
    public String getContractCode() {
        return contractCode;
    }

    /**
     * 合同编码
     */
    public void setContractCode(String contractCode) {
        this.contractCode = contractCode;
    }
    /**
     * 合同名称
     */
    public String getContractName() {
        return contractName;
    }

    /**
     * 合同名称
     */
    public void setContractName(String contractName) {
        this.contractName = contractName;
    }
    /**
     * 合同类别
     */
    public String getContractType() {
        return contractType;
    }

    /**
     * 合同类别
     */
    public void setContractType(String contractType) {
        this.contractType = contractType;
    }
    /**
     * 项目名称
     */
    public String getProjectName() {
        return projectName;
    }

    /**
     * 项目名称
     */
    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    /**
     * 项目id
     */
    public Long getProjectId() {
        return projectId;
    }

    /**
     * 项目id
     */
    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    /**
     * 组织名称
     */
    public String getOrgName() {
        return orgName;
    }

    /**
     * 组织名称
     */
    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    /**
     * 组织id
     */
    public Long getOrgId() {
        return orgId;
    }

    /**
     * 组织id
     */
    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    /**
     * 购方id
     */
    public Long getCustomerId() {
        return customerId;
    }

    /**
     * 购方id
     */
    public void setCustomerId(Long customerId) {
        this.customerId = customerId;
    }
    /**
     * 纳税人识别号
     */
    public String getCustomerCreditCode() {
        return customerCreditCode;
    }

    /**
     * 纳税人识别号
     */
    public void setCustomerCreditCode(String customerCreditCode) {
        this.customerCreditCode = customerCreditCode;
    }
    /**
     * 销方名称
     */
    public String getSupplierName() {
        return supplierName;
    }

    /**
     * 销方名称
     */
    public void setSupplierName(String supplierName) {
        this.supplierName = supplierName;
    }
    /**
     * 销方id
     */
    public Long getSupplierId() {
        return supplierId;
    }

    /**
     * 销方id
     */
    public void setSupplierId(Long supplierId) {
        this.supplierId = supplierId;
    }
    /**
     * 销方纳税人识别号
     */
    public String getSupplierCreditCode() {
        return supplierCreditCode;
    }

    /**
     * 销方纳税人识别号
     */
    public void setSupplierCreditCode(String supplierCreditCode) {
        this.supplierCreditCode = supplierCreditCode;
    }
    /**
     * 备注
     */
    public String getMemo() {
        return memo;
    }

    /**
     * 备注
     */
    public void setMemo(String memo) {
        this.memo = memo;
    }
    /**
     * 开票类型:1,有合同,2,无合同
     */
    public Integer getType() {
        return type;
    }

    /**
     * 开票类型:1,有合同,2,无合同
     */
    public void setType(Integer type) {
        this.type = type;
    }
    /**
     * 发票类型:1、增值税专用发票，2、增值税普通发票，3、其他；
     */
    public Long getInvoiceType() {
        return invoiceType;
    }

    public void setInvoiceType(Long invoiceType) {
        this.invoiceType = invoiceType;
    }

    /**
     * 发票类型名称:1、增值税专用发票，2、增值税普通发票，3、其他；
     */
    public String getInvoiceTypeName() {
        return invoiceTypeName;
    }

    /**
     * 发票类型名称:1、增值税专用发票，2、增值税普通发票，3、其他；
     */
    public void setInvoiceTypeName(String invoiceTypeName) {
        this.invoiceTypeName = invoiceTypeName;
    }
    /**
     * 发票号码
     */
    public String getInvoiceNumber() {
        return invoiceNumber;
    }

    /**
     * 发票号码
     */
    public void setInvoiceNumber(String invoiceNumber) {
        this.invoiceNumber = invoiceNumber;
    }
    /**
     * 发票代码
     */
    public String getInvoiceCode() {
        return invoiceCode;
    }

    /**
     * 发票代码
     */
    public void setInvoiceCode(String invoiceCode) {
        this.invoiceCode = invoiceCode;
    }
    /**
     * 开票日期
     */
    public java.util.Date getInvoiceDate() {
        return invoiceDate;
    }

    /**
     * 开票日期
     */
    public void setInvoiceDate(java.util.Date invoiceDate) {
        this.invoiceDate = invoiceDate;
    }
    /**
     * 发票金额（不含税）
     */
    public java.math.BigDecimal getInvoiceMny() {
        return invoiceMny;
    }

    /**
     * 发票金额（不含税）
     */
    public void setInvoiceMny(java.math.BigDecimal invoiceMny) {
        this.invoiceMny = invoiceMny;
    }
    /**
     * 税金
     */
    public java.math.BigDecimal getTaxMny() {
        return taxMny;
    }

    /**
     * 税金
     */
    public void setTaxMny(java.math.BigDecimal taxMny) {
        this.taxMny = taxMny;
    }
    /**
     * 价税合计
     */
    public java.math.BigDecimal getInvoiceTaxMny() {
        return invoiceTaxMny;
    }

    /**
     * 价税合计
     */
    public void setInvoiceTaxMny(java.math.BigDecimal invoiceTaxMny) {
        this.invoiceTaxMny = invoiceTaxMny;
    }
    /**
     * 单据状态（审批必须字段）
     */
    public Integer getBillState() {
        return billState;
    }

    /**
     * 单据状态（审批必须字段）
     */
    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    /**
     * 购方名称
     */
    public String getCustomerName() {
        return customerName;
    }

    /**
     * 购方名称
     */
    public void setCustomerName(String customerName) {
        this.customerName = customerName;
    }
    /**
     * 经办人名称
     */
    public String getEmployeeName() {
        return employeeName;
    }

    /**
     * 经办人名称
     */
    public void setEmployeeName(String employeeName) {
        this.employeeName = employeeName;
    }
    /**
     * 经办人
     */
    public Long getEmployeeId() {
        return employeeId;
    }

    /**
     * 经办人
     */
    public void setEmployeeId(Long employeeId) {
        this.employeeId = employeeId;
    }
    /**
     * 申请单id
     */
    public Long getApplyId() {
        return applyId;
    }

    /**
     * 申请单id
     */
    public void setApplyId(Long applyId) {
        this.applyId = applyId;
    }
    /**
     * 申请单编码
     */
    public String getApplyCode() {
        return applyCode;
    }

    /**
     * 申请单编码
     */
    public void setApplyCode(String applyCode) {
        this.applyCode = applyCode;
    }
    /**
     * 开票登记单id
     */
    public Long getRegistId() {
        return registId;
    }

    /**
     * 开票登记单id
     */
    public void setRegistId(Long registId) {
        this.registId = registId;
    }
    /**
     * 开票登记单code
     */
    public String getRegistCode() {
        return registCode;
    }

    /**
     * 开票登记单code
     */
    public void setRegistCode(String registCode) {
        this.registCode = registCode;
    }

    public String getInvoiceTaxMnyChn() {
        return invoiceTaxMnyChn;
    }

    public void setInvoiceTaxMnyChn(String invoiceTaxMnyChn) {
        this.invoiceTaxMnyChn = invoiceTaxMnyChn;
    }

    public String getInvoiceContent() {
        return invoiceContent;
    }

    public void setInvoiceContent(String invoiceContent) {
        this.invoiceContent = invoiceContent;
    }

    public Integer getOpenApplyType() {
        return openApplyType;
    }

    public void setOpenApplyType(Integer openApplyType) {
        this.openApplyType = openApplyType;
    }

    public BigDecimal getApplyMnyTax() {
        return applyMnyTax;
    }

    public void setApplyMnyTax(BigDecimal applyMnyTax) {
        this.applyMnyTax = applyMnyTax;
    }

    public Long getMoneyTypeId() {
        return moneyTypeId;
    }

    public void setMoneyTypeId(Long moneyTypeId) {
        this.moneyTypeId = moneyTypeId;
    }

    public String getBuyerBankAccount() {
        return buyerBankAccount;
    }

    public void setBuyerBankAccount(String buyerBankAccount) {
        this.buyerBankAccount = buyerBankAccount;
    }

    public String getBuyerAddrPhone() {
        return buyerAddrPhone;
    }

    public void setBuyerAddrPhone(String buyerAddrPhone) {
        this.buyerAddrPhone = buyerAddrPhone;
    }

    public String getSellerBankAccount() {
        return sellerBankAccount;
    }

    public void setSellerBankAccount(String sellerBankAccount) {
        this.sellerBankAccount = sellerBankAccount;
    }

    public String getSellerAddrPhone() {
        return sellerAddrPhone;
    }

    public void setSellerAddrPhone(String sellerAddrPhone) {
        this.sellerAddrPhone = sellerAddrPhone;
    }

    public Integer getOriginType() {
        return originType;
    }

    public void setOriginType(Integer originType) {
        this.originType = originType;
    }

    public Integer getRegist() {
        return regist;
    }

    public void setRegist(Integer regist) {
        this.regist = regist;
    }
}
